@@ -30,7 +30,7 @@ import termios
 
 logging.basicConfig(format='%(levelname)s:%(message)s')
 
-VERSION = '0.1.3'
+VERSION = '0.1.4'
 
 def term_size():
     buf = array.array('h', [0, 0])
@@ -115,8 +115,8 @@ class Issues(object):
         if len(self.issues) > 0:
             largest = max([issue["number"] for issue in self.issues])
         number = largest + 1
-        issue = {"status": "open", "number": number, "tag": tags, "date": today,
-                 "description": description}
+        issue = {"status": "open", "number": number, "tag": tags,
+                 "date": today, "description": description}
         self.issues.append(issue)
         self.print_short([issue])
         logging.info("Added a new issue:\n{}".format(issue))
@@ -192,24 +192,17 @@ class Issues(object):
         self.save_issues()
 
     def init(self, force, compress):
-        self.gzip_file = exists("ISSUES.gz")
-        if exists("ISSUES") or self.gzip_file:
+        if self.filename:
             if force:
                 now = datetime.today().strftime("%Y-%m-%d_%H%M%S")
-                if self.gzip_file:
-                    newfile = "ISSUES.gz_" + now
-                else:
-                    newfile = "ISSUES_" + now
+                newfile = self.filename + "_" + now
                 if exists(newfile):
                     logging.error("Could not rename old file. Filename "
                                   + "already exists.")
                     exit(1)
                 else:
                     try:
-                        if self.gzip_file:
-                            os.rename("ISSUES.gz", newfile)
-                        else:
-                            os.rename("ISSUES", newfile)
+                        os.rename(filename, newfile)
                         logging.info("Moved old issue file to {}"
                                      .format(newfile))
                     except OSError:
@@ -234,6 +227,7 @@ class Issues(object):
             for issue in self.issues:
                 if issue["number"] == number:
                     content = issue["description"]
+                    break
         return content
 
     def print_short(self, issuelist):
@@ -254,7 +248,7 @@ class Issues(object):
             for issue in issuelist:
                 for col in issue:
                     if len(str(issue[col])) > lens[col]:
-                            lens[col] = len(str(issue[col]))
+                        lens[col] = len(str(issue[col]))
         else:
             logging.warning("Issue list print requested but got nothing.")
             exit(1)
